from langchain_community.document_loaders import Docx2txtLoader

class DocxLoader():
    @classmethod
    def loader(cls, filename: str):
        #"./example_data/fake.docx"
       return Docx2txtLoader(filename)



from langchain_community.document_loaders import UnstructuredPowerPointLoader

class PptxLoader():
    @classmethod
    def loader(cls, filename: str):
        #"./example_data/fake-power-point.pptx"
        return UnstructuredPowerPointLoader(filename)



from langchain_community.document_loaders.image import UnstructuredImageLoader

class ImageLoader:
     @classmethod
     def loader(cls,filename):
         "./example_data/layout-parser-paper-screenshot.png"
         return UnstructuredImageLoader(filename)